' Usage: phalbum.vbs <sourceDirectory> <destinationDirectory> <albumName> [/F] [/S]

' Define constants.

Const cvsIllustrationDocument = 1
Const cvsHTMLFormat = 1

' Declare global variables.

Dim createFolder, separatePages
createFolder = False
separatePages = False


' Subroutine checks value for command line options.
' /F creates a new folder for the photo album.
' /S puts each picture on a separate page.
' It sets a global flag if an option is found.

Sub CheckOption(opt)

    ' Make sure the value is a string.

    If (VarType(opt) = vbString) Then

        ' Search for /F option. Note that the test accepts
        ' /f, too.

        If (InStr(UCase(opt), "/F")) Then
           createFolder = True
        End If

        ' Search for /S option. Note that the test accepts
        ' /s, too.

        If (InStr(UCase(opt), "/S")) Then
           separatePages = True
        End If

    End If
End Sub


' Function checks if a file is an image.
' The function recognizes JPEG, GIF, and TIFF files by
' searching for the respective extensions.

Function IsImageFile(fileName)

    IsImageFile = False

    ' Convert file name to upper case.

    Dim upName
    upName = UCase(fileName)

    ' Search file name for image extensions and return
    ' True if one is found.

    If (InStr(upName, ".JPG")) Then
        IsImageFile = True
        Exit Function
    End If

    If (InStr(upName, ".JPEG")) Then
        IsImageFile = True
        Exit Function
    End If

    If (InStr(upName, ".GIF")) Then
        IsImageFile = True
        Exit Function
    End If

    If (InStr(upName, ".TIF")) Then
        IsImageFile = True
        Exit Function
    End If

    If (InStr(upName, ".TIFF")) Then
        IsImageFile = True
        Exit Function
    End If

End Function


' Obtain command line arguments.

Dim args
Set args = WScript.Arguments

' Make sure there are at least three arguments for the source
' and destination folders and the name of the photo album.

If (args.Count >= 3) Then

    ' Store the first three arguments in variables and make
    ' sure they are strings.
    
    Dim srcDir, dstDir, album
    srcDir = args.Item(0)
    dstDir = args.Item(1)
    album = args.Item(2)

    If (VarType(srcDir) = vbString And VarType(dstDir) = vbString And VarType(album) = vbString) Then

        ' Check if there is a fourth argument and test it for
        ' command line options.

        If (args.Count > 3) Then
            Call CheckOption(args.Item(3))
        End If

        ' Check if there is a fifth argument and test it for
        ' command line options as well.

        If (args.Count > 4) Then
            Call CheckOption(args.Item(4))
        End If

        ' Start Canvas and create an illustration document.
        
        Dim cvApp
        Set cvApp = CreateObject("Canvas.Application")

        Dim doc
        Set doc = cvApp.Documents.Add(cvsIllustrationDocument)

        ' Create a file system object.

        Dim fso
        Set fso = CreateObject("Scripting.FileSystemObject")

        ' Mark the first pass through the loop.

        Dim firstPass
        firstPass = True

        ' Loop over all the files in the selected source folder.

        Dim srcFile
        For Each srcFile In fso.GetFolder(srcDir).Files
        
            ' If the current file is an image file, place it in
            ' the document on a new page.

            If (IsImageFile(srcFile.Name)) Then

                ' The first page gets created with the document.
                ' Avoid creating an additional one for the first
                ' image.

                If firstPass = False Then
            
                   ' Add a page to the document and set it as
                   ' active page.

                   Set pg = doc.Pages.Add
                   doc.ActivePage = pg
            
                End If
             
                ' Place the image in the document on the active page.

                doc.Place srcFile.Path
            
                ' Clear the first pass marker.

                firstPass = False

            End If
        Next

        ' Create a HTML export options object and set the command line options.

        Dim htmlOpt
        Set htmlOpt = cvApp.ExportFilters.DefaultHTMLExportOptions
        htmlOpt.CreateNewFolder = createFolder
        htmlOpt.SeparatePages = separatePages
    
        ' Save the document as HTML page to the destination folder and use
        ' the third command line argument as file name. The HTML export will
        ' automatically format the HTML page as a photo album according to
        ' the export options that are used.

        Dim dstPath
        dstPath = dstDir + "\"
        doc.SaveAs dstPath + album, cvsHTMLFormat, htmlOpt

        ' Dispose the used objects.
       
        Set htmlOpt = Nothing
        Set fso = Nothing
        Set cvApp = Nothing

    End If
End If
